Crate bareiss

Crate bareiss 

Utilities for random number generation

Bareiss algorithm calculates the determinant of an integer square matrix only using integer arithmetics.

Examples

use bareiss::bareiss_determinant;

let mut matrix = vec![1, 2, 3, 10];
assert_eq!(bareiss_determinant(&mut matrix, 2).unwrap(), 4);

Functions

bareiss_determinant
Bareiss algorithm calculates the determinant of an integer square matrix only using integer arithmetics.